@@ -9,14 +9,13 @@
 #include	<string.h>
 #include	<stdlib.h>
 #include	<errno.h>
+#include	<courier-unicode.h>
 
 #include	"rfc822hdr.h"
 #include	"rfc2047.h"
-#include	"../unicode/unicode.h"
 
 #if LIBIDN
-#include <idna.h>
-#include <stringprep.h>
+#include <idn2.h>
 #endif
 
 
@@ -93,7 +92,7 @@ static void rfc822_display_addr_cb(const char *chset,
 	memcpy(buf, content, cnt);
 	buf[cnt]=0;
 
-	ptr=libmail_u_convert_tobuf(buf, chset, s->chset, NULL);
+	ptr=unicode_convert_tobuf(buf, chset, s->chset, NULL);
 	free(buf);
 
 	if (ptr)
@@ -131,7 +130,7 @@ int rfc822_display_name_int(const struct rfc822a *rfcp, int index,
 
 	if (chset == NULL)
 	{
-		s.chset="iso-8859-1";
+		s.chset="utf-8";
 	}
 	else
 	{
@@ -322,7 +321,9 @@ int rfc822_display_addr_str(const char *tok,
 
 	if (chset != NULL)
 	{
+#if LIBIDN
 		int err=0;
+#endif
 		char *utf8_ptr;
 
 		if (p > tok)
@@ -342,7 +343,7 @@ int rfc822_display_addr_str(const char *tok,
 			memset(cpy, 0, s);
 			strcpy(cpy, p);
 
-			err=idna_to_unicode_8z8z(cpy, &utf8_ptr, 0);
+			err=idn2_to_unicode_8z8z(cpy, &utf8_ptr, 0);
 			free(cpy);
 		}
 
@@ -356,7 +357,7 @@ int rfc822_display_addr_str(const char *tok,
 			(*print_func)(p, strlen(p), ptr);
 		else
 		{
-			char *q=libmail_u_convert_tobuf(utf8_ptr,
+			char *q=unicode_convert_tobuf(utf8_ptr,
 							"utf-8",
 							chset, NULL);
 			if (q)
@@ -474,7 +475,7 @@ int rfc2047_print_unicodeaddr(const struct rfc822a *a,
 			if (strchr(RFC822_SPECIALS, nbuf.bufptr[i]))
 				break;
 
-		cpbuf=libmail_u_convert_tobuf(nbuf.bufptr, "utf-8", charset,
+		cpbuf=unicode_convert_tobuf(nbuf.bufptr, "utf-8", charset,
 					      NULL);
 
 		if (!cpbuf)
@@ -991,7 +992,7 @@ int rfc2047_decoder(const char *text,
 		}
 
 		if (i)
-			(*callback)("iso-8859-1", "", text, i, ptr);
+			(*callback)("utf-8", "", text, i, ptr);
 
 		text += i;
 
@@ -1006,7 +1007,7 @@ int rfc2047_decoder(const char *text,
 
 		if (rc == 0)
 		{
-			(*callback)("iso-8859-1", "", text, 2, ptr);
+			(*callback)("utf-8", "", text, 2, ptr);
 			text += 2;
 			continue;
 		}
